@@ -476,11 +476,10 @@ def update_consommation(product, policy, customer_name, fup_status, consumption)
         )
 
 
-def get_consommation_sum(customer):
+def get_consommation_sum(customer, date):
     """
     Fetches the last 30days consumptions of a customer
     """
-    thirty_days_ago = (dt.today() - timedelta(days=31)).strftime("%Y-%m-%d")
     sql = (
         "SELECT SUM(octets_in+octets_out) "
         "FROM cdr "
@@ -491,7 +490,7 @@ def get_consommation_sum(customer):
         "AND extract(HOUR FROM datetime) < 19 "
         "AND extract(HOUR FROM datetime) > 8 "
         "GROUP BY customer;"
-    ).format(customer=customer, date=thirty_days_ago)
+    ).format(customer=customer, date=date)
     try:
         with records.Database(si_database_url()) as db:
             rows = db.query(sql)
